import os, sys
from PyQt4 import QtGui, QtCore
from tubeMap_window import *

class TubeMapDisplay(QtGui.QMainWindow):
    def __init__(self, parent=None):
        #build parent user interface
        QtGui.QWidget.__init__(self, parent)
        self.ui = Ui_MainWindowTubeMap()
        self.ui.setupUi(self)
        
    def setupWindow(self):
        #self.ui.labelTubeMap.setText("Hello")
        self.pic = QtGui.QLabel(self)
        self.pic.setGeometry(0,0,800,400)
        #self.pic.setPixmap(QtGui.QPixmap(os.getcwd() + "/tubemap.gif"))
        self.pic.setPixmap(QtGui.QPixmap("/opt/tflapp/tubemap.png"))
        self.scrollArea = QtGui.QScrollArea(self)
        self.scrollArea.setWidget(self.pic)
        self.scrollArea.setGeometry(QtCore.QRect(0, 0, 800, 400))
        self.scrollArea.setWidgetResizable(True)
